function [f, sigDC, sigAC, fDC, fAC, hL, hD, Pdc] = allports(opt, sigDC, sigAC)
%[f, sigDC, sigAC, fDC, fAC, hL, hD, Pdc] = ACsweep(opt, Nsweep)
%
% ACsweep.m produces AC response as hL for each DOF for each PD,
% hD for each DOF for port(REFL1I, ASDC, REFLDDM, OMCDDM, POXDDM).
%
% hL(frequendcy, PD number, length DOF)
% hD(frequendcy, port number, length DOF)
%
% Pdc is DC power for carrier and RF in each field defined as 'FN' in "setup.m".
%
% Pdc(field number)


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
%%% Initial setting
  setup;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  

%  f = logspace(-1, 5, Nsweep)';
%  [sigDC, sigAC, mechTF, fDC, fAC] = compute(opt, [], f);


  % DC readout : nXXX(1)
  % f1 single demod I : nXXX(2)
  % f1 single demod Q : nXXX(3)
  % double demodulation : nXXX(4)
  % f2 single demod I : nXXX(8)
  % f2 single demod Q : nXXX(9)
  % 3*f1 demod I : nXXX(10)
  % 3*f1 demod Q : nXXX(11)
  % 3*f2 demod I : nXXX(12)
  % 3*f2 demod Q : nXXX(13)
  % 7*f1 demod I : nXXX(14)
  % 7*f1 demod Q : nXXX(15)

APN  = [nREFL(2), nREFL(3), nREFL(4), nREFL(8), nREFL(9), nREFL(10), nREFL(11), nREFL(14), nREFL(15),...
        nOMC(2),  nOMC(3),  nOMC(4),  nOMC(8),  nOMC(9),  nOMC(10),  nOMC(11),  nOMC(14),  nOMC(15),...
        nPOX(2),  nPOX(3),  nPOX(4),  nPOX(8),  nPOX(9),  nPOX(10),  nPOX(11),  nPOX(14),  nPOX(15)];
ALN  = [nREFL(2), nREFL(3), nREFL(4), nREFL(8), nREFL(9), nREFL(10), nREFL(11), nREFL(14), nREFL(15),...
        nOMC(2),  nOMC(3),  nOMC(4),  nOMC(8),  nOMC(9),  nOMC(10),  nOMC(11),  nOMC(14),  nOMC(15),...
        nPOX(2),  nPOX(3),  nPOX(4),  nPOX(8),  nPOX(9),  nPOX(10),  nPOX(11),  nPOX(14),  nPOX(15)];
finddemodphase(APN, ALN);

  % ==== Optical transfer functions
  for pn = 1:length(APN)
    if isempty(findstr('IM', opt.probe(PN(pn)).name))
      if isempty(findstr('HD', opt.probe(PN(pn)).name))
        if isempty(findstr('DC', opt.probe(PN(pn)).name))
          if isempty(findstr('Q', opt.probe(PN(pn)).name))
            % single I
            DN = 1; ST = 1;
            dDC = 1;
          else
            % single Q
            DN = -1; ST = -1;
            dDC = 1;
          end
        else
          % DC readout
          DN = 0; ST = 1;
          dDC = 2; % DCreadout counts signal twice, probably this is an Optickle's bug.  
        end
      else
        % for Homodyne
        DN = 1; ST = 1;
        dDC = 2;
      end
    else
      % for DDM
      DN = 3; ST = 1;
      dDC = 1;  
    end

    for dn = 0 : ST : DN
      % hXX is from mirror position to sensor signal (W/m)
      hPR = squeeze(sigAC(PN(pn) + dn, nPR, :)) * qeff / dDC;
      hBS = squeeze(sigAC(PN(pn) + dn, nBS, :)) * qeff / dDC;
      hSR = squeeze(sigAC(PN(pn) + dn, nSR, :)) * qeff / dDC;
      hIX = squeeze(sigAC(PN(pn) + dn, nIX, :)) * qeff / dDC;
      hIY = squeeze(sigAC(PN(pn) + dn, nIY, :)) * qeff / dDC;
      hEX = squeeze(sigAC(PN(pn) + dn, nEX, :)) * qeff / dDC;
      hEY = squeeze(sigAC(PN(pn) + dn, nEY, :)) * qeff / dDC;

      hL(:, PN(pn) + dn, Lp) = (hEX + hEY);
      hL(:, PN(pn) + dn, Lm) = (hEX - hEY);
      hL(:, PN(pn) + dn, lp) = (hPR);
      hL(:, PN(pn) + dn, lm) = ((hEX-hIX) - (hEY-hIY)); % or hBS;
      %hL(:, PN(pn) + dn, lm) = hBS - hPR / sqrt(2) + hSR / sqrt(2); % hBS
      hL(:, PN(pn) + dn, lsr) = (hSR);
    end

    %%% hD: 
    if isempty(findstr('IM', opt.probe(PN(pn)).name))
      if isempty(findstr('HD', opt.probe(PN(pn)).name))
        hD(:, pn, :) = hL(:, PN(pn), :);
      else
        hD(:, pn, :) = hL(:, PN(pn), :) - hL(:, PN(pn)+1, :);
      end
    else % for DDM
      hD(:, pn, :) = ((hL(:, PN(pn), :) + hL(:, PN(pn)+2, :))) / 2;
    end

    % === used for flat shotnoise
    Pdc(pn) = sum(abs(fDC(FN(pn), :).^2)) * qeff ;

    if Pdc(pn) > PdcMAX(pn)
      fprintf('DC power at %s is %gW with T = %g attenuator, higher than maximum acceptable power %gW. Put more attenuator!\n', ...
                     char(ND(pn)),  Pdc(pn), (opt.optic(AttN(pn)).m(1,2))^2, PdcMAX(pn));
    else
      fprintf('DC power at %s is %gW with T = %g attenuator, less than maximum power %gW. OK...\n', ...
                     char(ND(pn)), Pdc(pn), (opt.optic(AttN(pn)).m(1,2))^2, PdcMAX(pn));
    end
  end