% This is a main script to calculate loop noise for Advanced LIGO using
% Optickle engine written by Matt Evans.
%
% jsut run this "loopnoise.m", and then it produces DC responses, DDM
% coutour DDM contour plots, optical gain plots, noise plots, signal to
% noise, loop noise, loop noise with dynamic range limit, open loop TF with
% coupling, effctive opticalgain with coupling.
% 
% Change "optLIGO2.m" and "setup.m" for other parameters.

global rd PFf

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% initial setting

  %%% Chose optical configuration file 
  lsopt = dir('opt*.m'); % ls did not work on Mac and Linux
  J=1;
  for i = 1 : length(lsopt)
    a = lsopt(i).name;
    if isempty(findstr('demph', a))
    j = 1; 
    clear toptfiles
    while a(j) ~= '.'
      toptfiles(j) = a(j);
      j = j+1;
    end
    optfiles(J) = {toptfiles};
    J=J+1;
    end
  end
  
  str = sprintf('There are %g configuration files.', J-1);
  disp(str)      
  for j = 1 : J-1
    str = sprintf('%g: %s', j, char(optfiles(j)));
    disp(str)      
  end
  n1 = input('\n Which number do you want to run? ');
  PF = char(optfiles(n1));

  %%% Sweeping points number
  Nsweep = 50;

  %%% use Optickle engine
  cd Optickle;
  addpath(pwd);
  cd ../

  %%% re-phasing reset
  RePhaseOn = 0;


  % create the model
  opt = eval(char(PF));
  setup;
  
  % directry name to save plots
  PFf = PF;
  rd = [root '/' PF];
  if isdir(rd)
  else
    mkdir(rd);
  end
  fprintf(['All information is recorded at ' rd '/' PF '.txt\n']);
  diary([rd '/' PF '.txt']);
  diary on;
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Information

  fprintf('\n Loop noise calculation for %s.\n All plots are saved in %s\n', PF, rd);
  fprintf('Most important loop noise results are shown in Figure 600-603 in each result folder.\n\n');
  for rf = 1 : length([nSBa; nSBb]) 
    fprintf('Input power %6.7fW at %6.3fMHz\n', vArf(rf)^2, vFrf(rf)/1e6);
  end
  
  fprintf('\nX arm Finesse: %3.1f\n', pi * sqrt(opt.optic(nIX).m(1,1) * opt.optic(nEX).m(1,1))...
        / (1 - opt.optic(nIX).m(1,1) * opt.optic(nEX).m(1,1)));
  fprintf('Y arm Finesse: %3.1f\n', pi * sqrt(opt.optic(nIY).m(1,1) * opt.optic(nEY).m(1,1))...
        / (1 - opt.optic(nIY).m(1,1) * opt.optic(nEY).m(1,1)));

  Rxarm = (opt.optic(nIX).m(1,1) + (opt.optic(nIX).m(1,2)^2 * -opt.optic(nEX).m(1,1))...
          / (1 - opt.optic(nIX).m(1,1) * opt.optic(nEX).m(1,1)) )^2;
  Ryarm = (opt.optic(nIY).m(1,1) + (opt.optic(nIY).m(1,2)^2 * -opt.optic(nEY).m(1,1))...
            / (1 - opt.optic(nIY).m(1,1) * opt.optic(nEY).m(1,1)) )^2;
  fprintf('\nX arm power reflectivity: %1.4f\n', Rxarm);
  fprintf('Y arm power reflectivity: %1.4f\n', Ryarm);

  Rarm = (Rxarm + Ryarm)/2;
  fprintf('Power recycling gain for carrier (using averaged arm reflectivity) : %1.4f\n', (opt.optic(nPR).m(1,2)...
       / (1 + opt.optic(nPR).m(1,1) * sqrt(Rarm)) )^2);
  
  fprintf('\nOffset in SRM: %em (%3.3frad, %3.1fdeg, %3.1fdeg in BENCH, %3.1fdeg in FINESSE)\n',...
      opt.optic(nSR).pos, opt.optic(nSR).pos/opt.lambda, opt.optic(nSR).pos/opt.lambda * 360,...
      (opt.optic(nSR).pos/opt.lambda * 360 - 90) * 2, opt.optic(nSR).pos/opt.lambda * 360 -90 );
  fprintf('Offset in ETMX: %em\n', opt.optic(nEX).pos);
  fprintf('Offset in ETMY: %em\n', opt.optic(nEY).pos);
  fprintf('Quantum efficiency: %3.2f\n', qeff);

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
  %%% Main routine
    
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  %%% AC
  [f, sigDC, sigAC, fDC, fAC, hL, hD, Pdc] = ACsweep(opt, Nsweep);

  %%% Contour plot for DDM
  [RePhaseOn] = contourplot(opt, f, sigDC, hL);
  if RePhaseOn == 1
    close all
    return
  end
    
  %%% DC sweep
  DCsweep(opt, Nsweep);

  %%% Optical gain
  signal(opt, f, hD, Pdc);

  %%% Noise from vacuum
  [nVAC, tVAC, dVAC] = vacuum(opt, f, sigAC, fDC, Pdc);

  %%% close all graphs once
  close all
  
  %%% Signal to noise
  snr(opt, f, tVAC, hD);
  smatrix(opt, f, tVAC, hD, Pdc)

  %%% Coupling
  coupling(opt, f, sigDC, hD, tVAC, dVAC);

  %%% close all graphs
  close all
  
  diary off;