function [ ] = matrix(opt, f, hD, Pdc)
% matrix(opt, f, hD, Pdc)
%
% matrix.m produces optical gain matrix and shotnoise limit sensitivity. 
% Radiation pressure effect is included in the results. The unit is [W/m] 
% or [1/m] you choose in setup.m file.

global rd

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
%%% Initial setting
  setup;
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  

%%% AC

  f = logspace(-1, 5, Nsweep)';
  [sigDC, sigAC, mechTF, fDC, fAC] = compute(opt, [], f);

%%% Optical gain
PM  = [nREFL(1), nREFL(2), nREFL(3), nREFL(4), nREFL(8), nREFL(9),...
       nOMC(1), nOMC(2), nOMC(3), nOMC(4), nOMC(8), nOMC(9),...
       nPOX(1), nPOX(2), nPOX(3), nPOX(4), nPOX(8), nPOX(9)];
  %PN  = [nREFL(2), nHDa(1), nREFL(3)];
  for pn = 1 : length(PM)
    oTF(:, pn, :) = abs(hD(:, pn, :));
    oTFp(:, pn, :) = angle(hD(:, pn, :)) * (180 / pi);

    subplot(2, 1, 1)
    oTFg = zeros(length(PM), length(f));
    for b = 1 : length(PM)
      oTFg(b, :) = oTF(:, pn, b);
    end
    loglog(f, oTFg)
    clear lg
    for b = 1 : length(PM)
      lg(b) = {strcat(char(NC(b)))};
    end
    legend(lg)
    title(['Optical gain at ' char(ND(pn))])
    if MeterUnitOn == 1
      ylabel('1/m')
    else
      ylabel('W/m')
    end
    grid on

    subplot(2, 1, 2)
    semilogx(f, [oTFp(:, pn, Lp), oTFp(:, pn, Lm), oTFp(:, pn, lp), oTFp(:, pn, lm), oTFp(:, pn, lsr)]);
    xlabel('Hz')
    ylabel('phase [deg]')
    v = axis;
    axis([v(1) v(2) -180 180])
    grid on

    h = gcf;
    saveas(h, [rd '/' num2str(300 + pn) '_optgain_' char(NC(pn)) '.' ext]);
  end