function [xPos, sigDC, fDC] = sweeplm(optname, posStartX, posEndX, posStartY, posEndY, Nsweep)
% Sweep MICH macroscopicly in DRFPMI and generate plots.
% [xPos, sigDC, fDC] = sweeplm(optname, posStartX, posEndX, posStartY, posEndY, Nsweep)
% posStartX is a startine position of ITMX, and posEndX is an ending position of
% ITMX, and posStartY is a startine position of ITMY, and posEndY is an ending position of
% ITMY.
%
% Example:
% dl = 1.5 + 1;
% sweeplm(optAdLIGO45_9_NSNS, 1.4, 1.5, dl -1.4, dl - 1.5);

  % Check number of input arguments
  if nargin < 6
    Nsweep = 100;
  elseif nargin > 6
    error('Too Many Arguments!')
  end

  % prepare some variables
  opt = optname;
  sweepset;

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  %MICH sweep
  len1 = getLinkNum(opt, 'BS', 'BSPX');
  len2 = getLinkNum(opt, 'BS', 'BSPY');
  len = [len1, len2];
  posstart = [posStartX posStartX posStartY posStartY];
  posend = [posEndX posEndX posEndY posEndY];
  [xPos, sigDC, fDC] = sweepLink(opt, len, posstart, posend, Nsweep);
   
  %%% plot 
  fDCp = permute(fDC, [2, 3, 1]);

  subplot(2, 1, 1)
  n1 = getFieldAt(opt, nPR, 'fr');		% PR front input field
  semilogy(xPos(nIX, :), abs(fDCp(nSBa, :, n1)))
  title('ls macroscopic sweep: RF component powers in the PRC')
  legend(num2str(vFrf(nSBa) / 1e6))
  ylabel('Power[W]')
  grid on

  subplot(2, 1, 2)
  n2 = getFieldAt(opt, nSR, 'fr');		% SR front input field
  semilogy(xPos(nIX, :), abs(fDCp(nSBa, :, n2)))
  title('ls macroscopic sweep: RF component powers in the SRC')
  legend(num2str(vFrf(nSBa) / 1e6))
  xlabel('BS-ITMX distance[m]')
  ylabel('Power[W]')
  grid on

  %%% maximum power and its position
  for rf = 1 : length(nSBa) 
  [a,b] = max(abs(fDCp(nSBa(rf), :, n2)));
    fprintf('Maximum peak %gW for %gMHz at %8.8fm in the SRC.\n', a, vFrf(nSBa(rf))/1e6, xPos(nIX, b));
  end
  
  fprintf('\n');
  
  for rf = 1 : length(nSBa)
  [a,b] = min(abs(fDCp(nSBa(rf), :, n2)));
    fprintf('Minimum peak %gW for %gMHz at %8.8fm in the SRC.\n', a, vFrf(nSBa(rf))/1e6, xPos(nIX, b));
  end