% Sweep SRC macroscopicly in DRFPMI and generate plots.
% [xPos, sigDC, fDC] = sweeplSR(Nsweep)
% This displays carrier and RF powers, during a SRC sweep macroscopicly.

function [xPos, sigDC, fDC] = sweepls(optname, pos1, pos2, Nsweep)

  % Check number of input arguments
  if nargin < 4
    Nsweep = 100;
  elseif nargin > 4
    error('Too Many Arguments!')
  end

  
  % prepare some variables
  opt = optname;
  sweepset;

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % SRC sweep macroscopicly
  len = getLinkNum(opt, 'BS', 'SR');
  posstart = [pos1 pos1];
  posend = [pos2 pos2];
  [xPos, sigDC, fDC] = sweepLink(opt, len, posstart, posend, Nsweep);

  %%% plot 
  fDCp = permute(fDC, [2, 3, 1]);

  subplot(2, 1, 1)
  n1 = getFieldAt(opt, nPR, 'fr');		% PR front input field
  semilogy(xPos(nSR, :), abs(fDCp(nSBa, :, n1)))
  title('ls macroscopic sweep: RF component powers in the PRC')
  legend(num2str(vFrf(nSBa) / 1e6))
  grid on
  ylabel('Power[W]')

  subplot(2, 1, 2)
  n2 = getFieldAt(opt, nSR, 'fr');		% PR front input field
  semilogy(xPos(nSR, :), abs(fDCp(nSBa, :, n2)))
  title('ls macroscopic sweep: RF component powers in the SRC')
  legend(num2str(vFrf(nSBa) / 1e6))
  grid on
  xlabel('SRM-BS distance[m]')
  ylabel('Power[W]')

  %%% maximum power and its position
  for rf = 1 : length(nSBa) 
  [a,b]=max(abs(fDCp(nSBa(rf), :, n2)));
    fprintf('Maximum peak %gW for %gMHz at %8.8fm.\n', a, vFrf(nSBa(rf))/1e6, xPos(nSR, b));
  end
  
  fprintf('\n');

  for rf = 1 : length(nSBa) 
  [a,b]=min(abs(fDCp(nSBa(rf), :, n2)));
    fprintf('Minimum peak %gW for %gMHz at %8.8fm.\n', a, vFrf(nSBa(rf))/1e6, xPos(nSR, b));
  end